# Changelog

All notable changes to the Icon Task Manager with Zoom will be documented in this file.

## [1.0.0] - 2024-12-29

### ✨ Added
- **macOS Dock-like Zoom Effects**
  - Smooth zoom animations when hovering over task icons
  - Configurable zoom intensity (10-100%)
  - 9 anchor points (Center, Bottom, Top, Left, Right, Corners)
  - Adjustable timing controls (hover delay, reset delay, duration)
  - 7 easing curves (Linear, OutQuad, OutCubic, OutQuart, OutBack, OutElastic, OutBounce)
  
- **Custom Launch Animations**
  - 7 animation types:
    1. Classic Busy Indicator (default)
    2. Pulsing Icon - smooth scaling pulse
    3. Bouncing Icon - realistic physics-based bouncing
    4. Rotating Icon - continuous rotation
    5. Scaling Icon - complex bounce-scale with elastic settle
    6. Fading Icon - dramatic fade in/out
    7. Glow Effect - circular glow rings
  - Configurable duration (500-3000ms)
  - Configurable intensity (10-100%)
  - Automatic zoom override during startup animations

- **Enhanced Configuration UI**
  - New "Appearance" tab for zoom and animation settings
  - Conditional visibility for related settings
  - User-friendly controls with proper ranges and defaults
  - Real-time preview capabilities

### 🚀 Performance Improvements
- **Ultra-responsive updates**: 4ms update cycles for rapid mouse movements
- **Optimized caching systems** for expensive layout calculations
- **Fixed binding loops** that caused performance issues
- **Smart state management** for zoom effects
- **Efficient debouncing** for smooth rapid movements
- **Memory optimizations** throughout the codebase

### 🔧 Technical Enhancements
- **Transform-based animations** for reliable icon manipulation
- **Proper component lifecycle management**
- **Activity and virtual desktop integration**
- **Multi-screen support** with proper scaling
- **Theme integration** for consistent appearance
- **Zoom override during startup** to prevent interference

### 🛠️ Bug Fixes
- Fixed QIcon to string binding errors in launch animations
- Resolved icon duplication issues during animations
- Fixed bouncing animation anchor conflicts
- Corrected glow effect sizing issues
- Improved animation property reset handling
- Fixed Transform vs direct property binding issues

### 🎨 UI/UX Improvements
- **Smooth realistic bouncing** with proper physics
- **More dramatic fading effects** for better visibility
- **Distinct scaling vs pulsing animations**
- **Better glow effect proportions**
- **Consistent busy indicator overlay**
- **No zoom interference during startup animations**

### ⚙️ Configuration
- Added zoom configuration options to main.xml
- Proper enum choices for animation types and easing curves
- Sensible default values for all new settings
- Backward compatibility with existing configurations

### 📱 Compatibility
- **Plasma 6.0+** support
- Maintains compatibility with original task manager API
- Proper integration with existing Plasma themes
- Compatible with all original task manager features

## Based On
- `org.kde.plasma.taskmanager` - Original KDE Plasma task manager
- `org.kde.plasma.icontasks` - Icon-only variant

## Credits
- Original code: KDE Plasma Team, primarily Eike Hein
- Zoom effects: Enhanced implementation based on dock concepts
- Launch animations: Custom animation system
- Performance optimizations: Community contributions 