# Icon Task Manager with Zoom

An enhanced KDE Plasma widget based on the original `org.kde.plasma.taskmanager`, featuring macOS dock-like zoom effects and custom launch animations.

## ✨ Features

### 🔍 **macOS Dock-like Zoom Effects**
- **Smooth zoom animations** when hovering over task icons
- **Configurable zoom intensity** (10-100%)
- **Multiple anchor points** (Center, Bottom, Top, Corners)
- **Adjustable timing** (hover delay, reset delay, duration)
- **7 easing curves** (Linear, OutQuad, OutCubic, OutQuart, OutBack, OutElastic, OutBounce)
- **Performance optimized** with 4ms ultra-responsive updates
- **Smart state management** for rapid mouse movements

### 🎭 **Custom Launch Animations**
- **7 animation types** to choose from:
  1. **Classic Busy Indicator** (default) - Traditional spinning indicator overlay
  2. **Pulsing Icon** - Smooth scaling pulse effect
  3. **Bouncing Icon** - Realistic physics-based bouncing with multiple bounces
  4. **Rotating Icon** - Continuous rotation animation
  5. **Scaling Icon** - Complex bounce-scale with elastic settle
  6. **Fading Icon** - Dramatic fade in/out effect
  7. **Glow Effect** - Circular glow rings around the icon

- **Configurable parameters**:
  - Animation duration (500-3000ms)
  - Animation intensity (10-100%)
  - Automatic zoom override during startup

### 🚀 **Performance Enhancements**
- **Ultra-responsive** 4ms update cycles for rapid mouse movements
- **Optimized caching systems** for expensive layout calculations
- **Binding loop fixes** and memory optimizations
- **Zero performance impact** when using default settings

### 🎯 **Activity & Desktop Integration**
- **Virtual desktop aware** zoom effects
- **Activity-specific** task filtering
- **Multi-screen support** with proper scaling
- **Theme integration** for consistent appearance

## 📦 Installation

### Method 1: From KDE Store (Recommended)
1. Open **System Settings** → **Workspace** → **Plasma Style**
2. Click **Get New Plasma Widgets**
3. Search for "**Icon Task Manager with Zoom**"
4. Click **Install**

### Method 2: Manual Installation
1. Download the latest `.plasmoid` file from releases
2. Right-click on your panel → **Add Widgets**
3. Click **Get New Widgets** → **Install Widget From Local File**
4. Select the downloaded `.plasmoid` file

### Method 3: From Source
```bash
git clone https://github.com/kde-plasma-taskmanager-zoom
cd kde-plasma-taskmanager-zoom
kpackagetool6 --install . --type Plasma/Applet
```

## ⚙️ Configuration

Right-click the widget → **Configure Icon Task Manager with Zoom**

### Zoom Effects Tab
- **Magnify Factor**: Control zoom intensity (0.1-1.0)
- **Duration**: Animation speed (50-500ms)
- **Easing**: Choose from 7 animation curves
- **Hover Delay**: Delay before zoom starts (0-300ms)
- **Reset Delay**: Delay before zoom resets (0-300ms)
- **Anchor Point**: Where zoom originates from

### Launch Animations Tab
- **Animation Type**: Choose from 7 different animations
- **Duration**: How long each animation cycle lasts (500-3000ms)
- **Intensity**: Scale factor for animation effects (0.1-1.0)

## 🏗️ Building a Package

To create a `.plasmoid` package for distribution:

```bash
# Create the package
zip -r org.kde.plasma.icontasks.zoom.plasmoid . -x "*.git*" "*.md" "screenshots/*"

# Or use the KDE packaging tool
kpackagetool6 --type Plasma/Applet --generate-index .
```

## 🤝 Contributing

This project is based on the original KDE Plasma Task Manager. Contributions are welcome!

### Guidelines
- Follow KDE coding standards
- Test on multiple Plasma versions
- Include screenshots for UI changes
- Update documentation as needed

## 📄 License

This project is licensed under **GPL-2.0+**, maintaining compatibility with the original KDE Plasma Task Manager.

## 🙏 Credits

- **Original Task Manager**: KDE Plasma Team, primarily [Eike Hein](mailto:hein@kde.org)
- **Zoom & Animation Enhancements**: Community contributions
- **Performance Optimizations**: Various contributors

### Based On
- `org.kde.plasma.taskmanager` - The original KDE Plasma task manager
- `org.kde.plasma.icontasks` - Icon-only variant

## 🐛 Bug Reports

Found a bug? Please report it on our [GitHub Issues](https://github.com/kde-plasma-taskmanager-zoom/issues) page.

## 📸 Screenshots

![Zoom Effect Demo](screenshots/zoom-effect.gif)
*macOS dock-like zoom effect in action*

![Launch Animations](screenshots/launch-animations.gif)
*Custom launch animations showcase*

![Configuration Panel](screenshots/config-panel.png)
*Easy-to-use configuration interface*

---

**Enjoy your enhanced Plasma desktop experience!** 🚀 