#!/bin/bash

# Build script for Icon Task Manager with Zoom
# Creates a .plasmoid package ready for distribution

PACKAGE_NAME="org.kde.plasma.icontasks.zoom"
VERSION="1.0.0"
OUTPUT_FILE="${PACKAGE_NAME}-${VERSION}.plasmoid"

echo "🚀 Building Icon Task Manager with Zoom package..."

# Clean up any existing package
if [ -f "$OUTPUT_FILE" ]; then
    echo "📦 Removing existing package: $OUTPUT_FILE"
    rm "$OUTPUT_FILE"
fi

echo "📁 Creating package structure..."

# Create the plasmoid package (zip file)
# Exclude development files and directories
zip -r "$OUTPUT_FILE" . \
    -x "*.git*" \
    -x "*.md" \
    -x "screenshots/*" \
    -x "build-package.sh" \
    -x "*.log" \
    -x "/tmp/*" \
    -x "*.plasmoid"

if [ $? -eq 0 ]; then
    echo "✅ Package created successfully: $OUTPUT_FILE"
    echo "📏 Package size: $(du -h "$OUTPUT_FILE" | cut -f1)"
    echo ""
    echo "📋 Package contents:"
    unzip -l "$OUTPUT_FILE" | head -20
    echo ""
    echo "🎯 Ready for distribution!"
    echo ""
    echo "📤 To install locally:"
    echo "   kpackagetool6 --install $OUTPUT_FILE --type Plasma/Applet"
    echo ""
    echo "📤 To upload to KDE Store:"
    echo "   1. Go to https://store.kde.org/"
    echo "   2. Login with your KDE account"
    echo "   3. Click 'Upload Product'"
    echo "   4. Select category: Plasma Applets"
    echo "   5. Upload this file: $OUTPUT_FILE"
    echo ""
else
    echo "❌ Package creation failed!"
    exit 1
fi 